FileManagerController class

Constructors

FileManagerController()

Properties

getCurrentDirectory → Directory
Get current Directory.
no setter
getCurrentPath → String
Get current path, similar to getCurrentDirectory.
no setter
getPathNotifier → ValueNotifier<String>
Get ValueNotifier of path
no setter
getSortedBy → SortBy
The sorting type that is currently in use is returned.
no setter
getSortedByNotifier → ValueNotifier<SortBy>
Get ValueNotifier of SortedBy
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setCurrentPath ← String
Set current directory path by providing string of path, similar to openDirectory.
no getter
titleNotifier → ValueNotifier<String>
ValueNotifier of the current directory's basename
final

Methods

dispose() → void
Dispose FileManagerController
goToParentDirectory() → Future<void>
Jumps to the parent directory of currently opened directory if the parent is accessible.
isRootDirectory() → Future<bool>
return true if current directory is the root. false, if the current directory not on root of the stogare.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDirectory(FileSystemEntity entity) → void
Open directory by providing Directory.
sortBy(SortBy sortType) → void
setSortedBy is used to set the sorting type.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited